You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@subversion.apache.org by ko...@apache.org on 2022/11/21 15:46:37 UTC

svn commit: r1905439 - in /subversion/branches/pristines-on-demand-on-mwf/subversion: include/ include/private/ libsvn_client/ libsvn_wc/ svn/ tests/ tests/cmdline/ tests/libsvn_client/ tests/libsvn_wc/

Author: kotkov
Date: Mon Nov 21 15:46:37 2022
New Revision: 1905439

URL: http://svn.apache.org/viewvc?rev=1905439&view=rev
Log:
On the 'pristines-on-demand-on-mwf' branch: Drop plural from the newly
introduced term `store_pristines`, turning it into `store_pristine`.

The new term can be read as "store pristine (contents)" and is slighly more
generic, allowing to use it as-is in some additional contexts.

Rename and update all relevant and dependent names in the code.

Note: This change also renames the field in the db schema, so the previously
created working copies of the unreleased f32 format will stop working.

* subversion/include/private/svn_wc_private.h,
* subversion/include/svn_client.h,
* subversion/libsvn_client/checkout.c,
* subversion/libsvn_client/client.h,
* subversion/libsvn_client/upgrade.c,
* subversion/libsvn_wc/adm_files.c,
* subversion/libsvn_wc/info.c,
* subversion/libsvn_wc/textbase.c,
* subversion/libsvn_wc/upgrade.c,
* subversion/libsvn_wc/wc-metadata.sql,
* subversion/libsvn_wc/wc-queries.sql,
* subversion/libsvn_wc/wc.h,
* subversion/libsvn_wc/wc_db.c,
* subversion/libsvn_wc/wc_db.h,
* subversion/libsvn_wc/wc_db_pristine.c,
* subversion/libsvn_wc/wc_db_private.h,
* subversion/libsvn_wc/wc_db_wcroot.c,
* subversion/svn/checkout-cmd.c,
* subversion/svn/cl.h,
* subversion/svn/svn.c,
* subversion/tests/cmdline/pristines_on_demand_tests.py,
* subversion/tests/libsvn_client/client-test.c,
* subversion/tests/libsvn_client/conflicts-test.c,
* subversion/tests/libsvn_wc/entries-compat.c,
* subversion/tests/libsvn_wc/utils.c,
* subversion/tests/svn_test.h,
* subversion/tests/svn_test_main.c:
  (*): Rename `--store-pristines` and `store_pristines` to
   `--store-pristine` and `store_pristine` respectively.
   Adjust the comments and related names.

Modified:
    subversion/branches/pristines-on-demand-on-mwf/subversion/include/private/svn_wc_private.h
    subversion/branches/pristines-on-demand-on-mwf/subversion/include/svn_client.h
    subversion/branches/pristines-on-demand-on-mwf/subversion/libsvn_client/checkout.c
    subversion/branches/pristines-on-demand-on-mwf/subversion/libsvn_client/client.h
    subversion/branches/pristines-on-demand-on-mwf/subversion/libsvn_client/upgrade.c
    subversion/branches/pristines-on-demand-on-mwf/subversion/libsvn_wc/adm_files.c
    subversion/branches/pristines-on-demand-on-mwf/subversion/libsvn_wc/info.c
    subversion/branches/pristines-on-demand-on-mwf/subversion/libsvn_wc/textbase.c
    subversion/branches/pristines-on-demand-on-mwf/subversion/libsvn_wc/upgrade.c
    subversion/branches/pristines-on-demand-on-mwf/subversion/libsvn_wc/wc-metadata.sql
    subversion/branches/pristines-on-demand-on-mwf/subversion/libsvn_wc/wc-queries.sql
    subversion/branches/pristines-on-demand-on-mwf/subversion/libsvn_wc/wc.h
    subversion/branches/pristines-on-demand-on-mwf/subversion/libsvn_wc/wc_db.c
    subversion/branches/pristines-on-demand-on-mwf/subversion/libsvn_wc/wc_db.h
    subversion/branches/pristines-on-demand-on-mwf/subversion/libsvn_wc/wc_db_pristine.c
    subversion/branches/pristines-on-demand-on-mwf/subversion/libsvn_wc/wc_db_private.h
    subversion/branches/pristines-on-demand-on-mwf/subversion/libsvn_wc/wc_db_wcroot.c
    subversion/branches/pristines-on-demand-on-mwf/subversion/svn/checkout-cmd.c
    subversion/branches/pristines-on-demand-on-mwf/subversion/svn/cl.h
    subversion/branches/pristines-on-demand-on-mwf/subversion/svn/svn.c
    subversion/branches/pristines-on-demand-on-mwf/subversion/tests/cmdline/pristines_on_demand_tests.py
    subversion/branches/pristines-on-demand-on-mwf/subversion/tests/libsvn_client/client-test.c
    subversion/branches/pristines-on-demand-on-mwf/subversion/tests/libsvn_client/conflicts-test.c
    subversion/branches/pristines-on-demand-on-mwf/subversion/tests/libsvn_wc/entries-compat.c
    subversion/branches/pristines-on-demand-on-mwf/subversion/tests/libsvn_wc/utils.c
    subversion/branches/pristines-on-demand-on-mwf/subversion/tests/svn_test.h
    subversion/branches/pristines-on-demand-on-mwf/subversion/tests/svn_test_main.c

Modified: subversion/branches/pristines-on-demand-on-mwf/subversion/include/private/svn_wc_private.h
URL: http://svn.apache.org/viewvc/subversion/branches/pristines-on-demand-on-mwf/subversion/include/private/svn_wc_private.h?rev=1905439&r1=1905438&r2=1905439&view=diff
==============================================================================
--- subversion/branches/pristines-on-demand-on-mwf/subversion/libsvn_client/checkout.c (original)
+++ subversion/branches/pristines-on-demand-on-mwf/subversion/libsvn_client/checkout.c Mon Nov 21 15:46:37 2022
@@ -54,7 +54,7 @@ initialize_area(int target_format,
                 const char *local_abspath,
                 const svn_client__pathrev_t *pathrev,
                 svn_depth_t depth,
-                svn_boolean_t store_pristines,
+                svn_boolean_t store_pristine,
                 svn_client_ctx_t *ctx,
                 apr_pool_t *pool)
 {
@@ -65,7 +65,7 @@ initialize_area(int target_format,
   SVN_ERR(svn_wc__ensure_adm(ctx->wc_ctx,
                              target_format, local_abspath, pathrev->url,
                              pathrev->repos_root_url, pathrev->repos_uuid,
-                             pathrev->rev, depth, store_pristines, pool));
+                             pathrev->rev, depth, store_pristine, pool));
   return SVN_NO_ERROR;
 }
 
@@ -81,13 +81,13 @@ svn_client__checkout_internal(svn_revnum
                               svn_boolean_t ignore_externals,
                               svn_boolean_t allow_unver_obstructions,
                               const svn_version_t *wc_format_version,
-                              svn_tristate_t store_pristines,
+                              svn_tristate_t store_pristine,
                               svn_ra_session_t *ra_session,
                               svn_client_ctx_t *ctx,
                               apr_pool_t *scratch_pool)
 {
   int target_format;
-  svn_boolean_t target_store_pristines;
+  svn_boolean_t target_store_pristine;
   svn_node_kind_t kind;
   svn_client__pathrev_t *pathrev;
   svn_opt_revision_t resolved_rev = { svn_opt_revision_number };
@@ -103,10 +103,10 @@ svn_client__checkout_internal(svn_revnum
       && (revision->kind != svn_opt_revision_head))
     return svn_error_create(SVN_ERR_CLIENT_BAD_REVISION, NULL, NULL);
 
-  if (wc_format_version == NULL && store_pristines == svn_tristate_unknown)
+  if (wc_format_version == NULL && store_pristine == svn_tristate_unknown)
     {
       SVN_ERR(svn_wc__settings_from_context(&target_format,
-                                            &target_store_pristines,
+                                            &target_store_pristine,
                                             ctx->wc_ctx, local_abspath,
                                             scratch_pool));
     }
@@ -117,12 +117,12 @@ svn_client__checkout_internal(svn_revnum
       SVN_ERR(svn_wc__format_from_version(&target_format, wc_format_version,
                                           scratch_pool));
 
-      SVN_ERR_ASSERT(store_pristines != svn_tristate_unknown);
+      SVN_ERR_ASSERT(store_pristine != svn_tristate_unknown);
 
-      if (store_pristines == svn_tristate_true)
-        target_store_pristines = TRUE;
+      if (store_pristine == svn_tristate_true)
+        target_store_pristine = TRUE;
       else
-        target_store_pristines = FALSE;
+        target_store_pristine = FALSE;
     }
 
   /* Get the RA connection, if needed. */
@@ -176,7 +176,7 @@ svn_client__checkout_internal(svn_revnum
          URL, revnum, and an 'incomplete' flag.  */
       SVN_ERR(svn_io_make_dir_recursively(local_abspath, scratch_pool));
       SVN_ERR(initialize_area(target_format, local_abspath, pathrev, depth,
-                              target_store_pristines, ctx, scratch_pool));
+                              target_store_pristine, ctx, scratch_pool));
     }
   else if (kind == svn_node_dir)
     {
@@ -189,23 +189,23 @@ svn_client__checkout_internal(svn_revnum
       if (! present_format)
         {
           SVN_ERR(initialize_area(target_format, local_abspath, pathrev, depth,
-                                  target_store_pristines, ctx, scratch_pool));
+                                  target_store_pristine, ctx, scratch_pool));
         }
       else
         {
-          svn_boolean_t wc_store_pristines;
+          svn_boolean_t wc_store_pristine;
 
-          SVN_ERR(svn_wc__get_settings(NULL, &wc_store_pristines, ctx->wc_ctx,
+          SVN_ERR(svn_wc__get_settings(NULL, &wc_store_pristine, ctx->wc_ctx,
                                        local_abspath, scratch_pool));
 
-          if ((target_store_pristines && !wc_store_pristines) ||
-              (!target_store_pristines && wc_store_pristines))
+          if ((target_store_pristine && !wc_store_pristine) ||
+              (!target_store_pristine && wc_store_pristine))
             {
               return svn_error_createf(
                   SVN_ERR_WC_INCOMPATIBLE_SETTINGS, NULL,
                   _("'%s' is an existing working copy with different '%s' setting"),
                   svn_dirent_local_style(local_abspath, scratch_pool),
-                  "store-pristines");
+                  "store-pristine");
             }
 
           /* Get PATH's URL. */
@@ -261,7 +261,7 @@ svn_client_checkout4(svn_revnum_t *resul
                      svn_boolean_t ignore_externals,
                      svn_boolean_t allow_unver_obstructions,
                      const svn_version_t *wc_format_version,
-                     svn_tristate_t store_pristines,
+                     svn_tristate_t store_pristine,
                      svn_client_ctx_t *ctx,
                      apr_pool_t *pool)
 {
@@ -271,15 +271,15 @@ svn_client_checkout4(svn_revnum_t *resul
 
   SVN_ERR(svn_dirent_get_absolute(&local_abspath, path, pool));
 
-  if (store_pristines == svn_tristate_unknown)
-    store_pristines = svn_tristate_true;
+  if (store_pristine == svn_tristate_unknown)
+    store_pristine = svn_tristate_true;
 
   /* A NULL wc_format_version translates to the minimum compatible version. */
   if (!wc_format_version)
     {
       wc_format_version = svn_client_default_wc_version(pool);
 
-      if (store_pristines == svn_tristate_false)
+      if (store_pristine == svn_tristate_false)
         {
           const svn_version_t *required_version =
             svn_client__compatible_wc_version_pristines_on_demand(pool);
@@ -298,7 +298,7 @@ svn_client_checkout4(svn_revnum_t *resul
                                       ignore_externals,
                                       allow_unver_obstructions,
                                       wc_format_version,
-                                      store_pristines,
+                                      store_pristine,
                                       NULL /* ra_session */,
                                       ctx, pool);
   if (sleep_here)

Modified: subversion/branches/pristines-on-demand-on-mwf/subversion/libsvn_client/client.h
URL: http://svn.apache.org/viewvc/subversion/branches/pristines-on-demand-on-mwf/subversion/libsvn_client/client.h?rev=1905439&r1=1905438&r2=1905439&view=diff
==============================================================================
--- subversion/branches/pristines-on-demand-on-mwf/subversion/libsvn_client/client.h (original)
+++ subversion/branches/pristines-on-demand-on-mwf/subversion/libsvn_client/client.h Mon Nov 21 15:46:37 2022
@@ -543,14 +543,14 @@ svn_client__update_internal(svn_revnum_t
    to the WC_FORMAT_VERSION of the client.  The format of any existing working
    copy will remain unchanged.
 
-   If STORE_PRISTINES is svn_tristate_true, the pristine contents of all
-   files in the working copy will be stored on disk.  If STORE_PRISTINES is
+   If STORE_PRISTINE is svn_tristate_true, the pristine contents of all
+   files in the working copy will be stored on disk.  If STORE_PRISTINE is
    svn_tristate_false, the pristine contents will be fetched on-demand when
    required by the operation.
 
-   If WC_FORMAT_VERSION is NULL and STORE_PRISTINES is svn_tristate_unknown, the
+   If WC_FORMAT_VERSION is NULL and STORE_PRISTINE is svn_tristate_unknown, the
    settings will be determined from context (see svn_wc__settings_from_context).
-   Otherwise, both WC_FORMAT_VERSION and STORE_PRISTINES must be defined.
+   Otherwise, both WC_FORMAT_VERSION and STORE_PRISTINE must be defined.
 
    If RA_SESSION is NOT NULL, it may be used to avoid creating a new
    session. The session may point to a different URL after returning.
@@ -566,7 +566,7 @@ svn_client__checkout_internal(svn_revnum
                               svn_boolean_t ignore_externals,
                               svn_boolean_t allow_unver_obstructions,
                               const svn_version_t *wc_format_version,
-                              svn_tristate_t store_pristines,
+                              svn_tristate_t store_pristine,
                               svn_ra_session_t *ra_session,
                               svn_client_ctx_t *ctx,
                               apr_pool_t *pool);

Modified: subversion/branches/pristines-on-demand-on-mwf/subversion/libsvn_client/upgrade.c
URL: http://svn.apache.org/viewvc/subversion/branches/pristines-on-demand-on-mwf/subversion/libsvn_client/upgrade.c?rev=1905439&r1=1905438&r2=1905439&view=diff
==============================================================================
--- subversion/branches/pristines-on-demand-on-mwf/subversion/libsvn_client/upgrade.c (original)
+++ subversion/branches/pristines-on-demand-on-mwf/subversion/libsvn_client/upgrade.c Mon Nov 21 15:46:37 2022
@@ -93,14 +93,14 @@ static svn_error_t *
 upgrade_externals_from_properties(svn_client_ctx_t *ctx,
                                   const char *local_abspath,
                                   int wc_format,
-                                  svn_boolean_t store_pristines,
+                                  svn_boolean_t store_pristine,
                                   struct repos_info_baton *info_baton,
                                   apr_pool_t *scratch_pool);
 
 static svn_error_t *
 upgrade_internal(const char *path,
                  int wc_format,
-                 svn_boolean_t store_pristines,
+                 svn_boolean_t store_pristine,
                  svn_client_ctx_t *ctx,
                  apr_pool_t *scratch_pool)
 {
@@ -119,7 +119,7 @@ upgrade_internal(const char *path,
 
   SVN_ERR(svn_dirent_get_absolute(&local_abspath, path, scratch_pool));
   SVN_ERR(svn_wc__upgrade(ctx->wc_ctx, local_abspath,
-                          wc_format, store_pristines,
+                          wc_format, store_pristine,
                           fetch_repos_info, &info_baton,
                           ctx->cancel_func, ctx->cancel_baton,
                           ctx->notify_func2, ctx->notify_baton2,
@@ -158,7 +158,7 @@ upgrade_internal(const char *path,
           if (kind == svn_node_dir)
             {
               svn_error_t *err = upgrade_internal(ext_abspath, wc_format,
-                                                  store_pristines, ctx,
+                                                  store_pristine, ctx,
                                                   iterpool);
 
               if (err)
@@ -184,7 +184,7 @@ upgrade_internal(const char *path,
          (There is no way to detect the difference from libsvn_client :( ) */
 
       SVN_ERR(upgrade_externals_from_properties(ctx, local_abspath,
-                                                wc_format, store_pristines,
+                                                wc_format, store_pristine,
                                                 &info_baton, scratch_pool));
     }
 
@@ -288,7 +288,7 @@ svn_client__compatible_wc_version_pristi
 static svn_error_t *
 upgrade_external_item(svn_client_ctx_t *ctx,
                       int wc_format,
-                      svn_boolean_t store_pristines,
+                      svn_boolean_t store_pristine,
                       const char *externals_parent_abspath,
                       const char *externals_parent_url,
                       const char *externals_parent_repos_root_url,
@@ -331,7 +331,7 @@ upgrade_external_item(svn_client_ctx_t *
     {
       svn_error_clear(err);
 
-      SVN_ERR(upgrade_internal(external_abspath, wc_format, store_pristines,
+      SVN_ERR(upgrade_internal(external_abspath, wc_format, store_pristine,
                                ctx, scratch_pool));
     }
   else if (err)
@@ -406,7 +406,7 @@ static svn_error_t *
 upgrade_externals_from_properties(svn_client_ctx_t *ctx,
                                   const char *local_abspath,
                                   int wc_format,
-                                  svn_boolean_t store_pristines,
+                                  svn_boolean_t store_pristine,
                                   struct repos_info_baton *info_baton,
                                   apr_pool_t *scratch_pool)
 {
@@ -495,7 +495,7 @@ upgrade_externals_from_properties(svn_cl
           item = APR_ARRAY_IDX(externals_p, i, svn_wc_external_item2_t*);
 
           svn_pool_clear(inner_iterpool);
-          err = upgrade_external_item(ctx, wc_format, store_pristines,
+          err = upgrade_external_item(ctx, wc_format, store_pristine,
                                       externals_parent_abspath,
                                       externals_parent_url,
                                       externals_parent_repos_root_url,

Modified: subversion/branches/pristines-on-demand-on-mwf/subversion/libsvn_wc/adm_files.c
URL: http://svn.apache.org/viewvc/subversion/branches/pristines-on-demand-on-mwf/subversion/libsvn_wc/adm_files.c?rev=1905439&r1=1905438&r2=1905439&view=diff
==============================================================================
--- subversion/branches/pristines-on-demand-on-mwf/subversion/libsvn_wc/adm_files.c (original)
+++ subversion/branches/pristines-on-demand-on-mwf/subversion/libsvn_wc/adm_files.c Mon Nov 21 15:46:37 2022
@@ -207,7 +207,7 @@ init_adm(svn_wc__db_t *db,
          const char *repos_uuid,
          svn_revnum_t initial_rev,
          svn_depth_t depth,
-         svn_boolean_t store_pristines,
+         svn_boolean_t store_pristine,
          apr_pool_t *pool)
 {
   /* First, make an empty administrative area. */
@@ -229,7 +229,7 @@ init_adm(svn_wc__db_t *db,
   /* Create the SDB. */
   SVN_ERR(svn_wc__db_init(db, target_format, local_abspath,
                           repos_relpath, repos_root_url, repos_uuid,
-                          initial_rev, depth, store_pristines, pool));
+                          initial_rev, depth, store_pristine, pool));
 
   /* Stamp ENTRIES and FORMAT files for old clients.  */
   SVN_ERR(svn_io_file_create(svn_wc__adm_child(local_abspath,
@@ -255,7 +255,7 @@ svn_wc__internal_ensure_adm(svn_wc__db_t
                             const char *repos_uuid,
                             svn_revnum_t revision,
                             svn_depth_t depth,
-                            svn_boolean_t store_pristines,
+                            svn_boolean_t store_pristine,
                             apr_pool_t *scratch_pool)
 {
   int present_format;
@@ -267,7 +267,7 @@ svn_wc__internal_ensure_adm(svn_wc__db_t
   svn_wc__db_status_t status;
   const char *db_repos_relpath, *db_repos_root_url, *db_repos_uuid;
   svn_revnum_t db_revision;
-  svn_boolean_t wc_store_pristines;
+  svn_boolean_t wc_store_pristine;
 
   SVN_ERR_ASSERT(svn_dirent_is_absolute(local_abspath));
   SVN_ERR_ASSERT(url != NULL);
@@ -287,7 +287,7 @@ svn_wc__internal_ensure_adm(svn_wc__db_t
         _("Working copy format %d can't be created by client version %s."),
         target_format, SVN_VER_NUM);
 
-  if (target_format < SVN_WC__PRISTINES_ON_DEMAND_VERSION && !store_pristines)
+  if (target_format < SVN_WC__PRISTINES_ON_DEMAND_VERSION && !store_pristine)
     return svn_error_createf(
         SVN_ERR_WC_UNSUPPORTED_FORMAT, NULL,
         _("Working copy format %d does not support the requested capabilities"),
@@ -302,7 +302,7 @@ svn_wc__internal_ensure_adm(svn_wc__db_t
     {
       return svn_error_trace(init_adm(db, target_format, local_abspath,
                                       repos_relpath, repos_root_url, repos_uuid,
-                                      revision, depth, store_pristines,
+                                      revision, depth, store_pristine,
                                       scratch_pool));
     }
   else if (present_format != target_format)
@@ -313,17 +313,17 @@ svn_wc__internal_ensure_adm(svn_wc__db_t
           target_format, present_format, local_abspath);
     }
 
-  SVN_ERR(svn_wc__db_get_settings(NULL, &wc_store_pristines, db,
+  SVN_ERR(svn_wc__db_get_settings(NULL, &wc_store_pristine, db,
                                   local_abspath, scratch_pool));
 
-  if ((store_pristines && !wc_store_pristines) ||
-      (!store_pristines && wc_store_pristines))
+  if ((store_pristine && !wc_store_pristine) ||
+      (!store_pristine && wc_store_pristine))
     {
       return svn_error_createf(
           SVN_ERR_WC_INCOMPATIBLE_SETTINGS, NULL,
           _("'%s' is an existing working copy with different '%s' setting"),
           svn_dirent_local_style(local_abspath, scratch_pool),
-          "store-pristines");
+          "store-pristine");
     }
 
   SVN_ERR(svn_wc__db_read_info(&status, NULL,
@@ -411,13 +411,13 @@ svn_wc__ensure_adm(svn_wc_context_t *wc_
                    const char *repos_uuid,
                    svn_revnum_t revision,
                    svn_depth_t depth,
-                   svn_boolean_t store_pristines,
+                   svn_boolean_t store_pristine,
                    apr_pool_t *scratch_pool)
 {
   return svn_error_trace(
     svn_wc__internal_ensure_adm(wc_ctx->db, target_format, local_abspath,
                                 url, repos_root_url, repos_uuid, revision,
-                                depth, store_pristines, scratch_pool));
+                                depth, store_pristine, scratch_pool));
 }
 
 svn_error_t *

Modified: subversion/branches/pristines-on-demand-on-mwf/subversion/libsvn_wc/info.c
URL: http://svn.apache.org/viewvc/subversion/branches/pristines-on-demand-on-mwf/subversion/libsvn_wc/info.c?rev=1905439&r1=1905438&r2=1905439&view=diff
==============================================================================
--- subversion/branches/pristines-on-demand-on-mwf/subversion/libsvn_wc/info.c (original)
+++ subversion/branches/pristines-on-demand-on-mwf/subversion/libsvn_wc/info.c Mon Nov 21 15:46:37 2022
@@ -559,12 +559,12 @@ svn_wc__get_info(svn_wc_context_t *wc_ct
 
 svn_error_t *
 svn_wc__get_settings(int *format_p,
-                     svn_boolean_t *store_pristines_p,
+                     svn_boolean_t *store_pristine_p,
                      svn_wc_context_t *wc_ctx,
                      const char *local_abspath,
                      apr_pool_t *scratch_pool)
 {
-  SVN_ERR(svn_wc__db_get_settings(format_p, store_pristines_p, wc_ctx->db,
+  SVN_ERR(svn_wc__db_get_settings(format_p, store_pristine_p, wc_ctx->db,
                                   local_abspath, scratch_pool));
 
   return SVN_NO_ERROR;

Modified: subversion/branches/pristines-on-demand-on-mwf/subversion/libsvn_wc/textbase.c
URL: http://svn.apache.org/viewvc/subversion/branches/pristines-on-demand-on-mwf/subversion/libsvn_wc/textbase.c?rev=1905439&r1=1905438&r2=1905439&view=diff
==============================================================================
--- subversion/branches/pristines-on-demand-on-mwf/subversion/libsvn_wc/textbase.c (original)
+++ subversion/branches/pristines-on-demand-on-mwf/subversion/libsvn_wc/textbase.c Mon Nov 21 15:46:37 2022
@@ -527,14 +527,14 @@ svn_wc__textbase_sync(svn_wc_context_t *
                       void *cancel_baton,
                       apr_pool_t *scratch_pool)
 {
-  svn_boolean_t store_pristines;
+  svn_boolean_t store_pristine;
   textbase_sync_baton_t baton = {0};
 
   SVN_ERR_ASSERT(svn_dirent_is_absolute(local_abspath));
 
-  SVN_ERR(svn_wc__db_get_settings(NULL, &store_pristines, wc_ctx->db,
+  SVN_ERR(svn_wc__db_get_settings(NULL, &store_pristine, wc_ctx->db,
                                   local_abspath, scratch_pool));
-  if (store_pristines)
+  if (store_pristine)
     return SVN_NO_ERROR;
 
   baton.db = wc_ctx->db;

Modified: subversion/branches/pristines-on-demand-on-mwf/subversion/libsvn_wc/upgrade.c
URL: http://svn.apache.org/viewvc/subversion/branches/pristines-on-demand-on-mwf/subversion/libsvn_wc/upgrade.c?rev=1905439&r1=1905438&r2=1905439&view=diff
==============================================================================
--- subversion/branches/pristines-on-demand-on-mwf/subversion/libsvn_wc/upgrade.c (original)
+++ subversion/branches/pristines-on-demand-on-mwf/subversion/libsvn_wc/upgrade.c Mon Nov 21 15:46:37 2022
@@ -2026,7 +2026,7 @@ svn_error_t *
 svn_wc__upgrade(svn_wc_context_t *wc_ctx,
                 const char *local_abspath,
                 int target_format,
-                svn_boolean_t store_pristines,
+                svn_boolean_t store_pristine,
                 svn_wc_upgrade_get_repos_info_t repos_info_func,
                 void *repos_info_baton,
                 svn_cancel_func_t cancel_func,
@@ -2129,7 +2129,7 @@ svn_wc__upgrade(svn_wc_context_t *wc_ctx
                                    &data.repos_id, &data.wc_id,
                                    db, target_format, data.root_abspath,
                                    this_dir->repos, this_dir->uuid,
-                                   store_pristines, scratch_pool));
+                                   store_pristine, scratch_pool));
 
   /* Migrate the entries over to the new database.
    ### We need to think about atomicity here.

Modified: subversion/branches/pristines-on-demand-on-mwf/subversion/libsvn_wc/wc-metadata.sql
URL: http://svn.apache.org/viewvc/subversion/branches/pristines-on-demand-on-mwf/subversion/libsvn_wc/wc-metadata.sql?rev=1905439&r1=1905438&r2=1905439&view=diff
==============================================================================
--- subversion/branches/pristines-on-demand-on-mwf/subversion/libsvn_wc/wc-metadata.sql (original)
+++ subversion/branches/pristines-on-demand-on-mwf/subversion/libsvn_wc/wc-metadata.sql Mon Nov 21 15:46:37 2022
@@ -782,7 +782,7 @@ END;
 /* This table contains settings of a working copy, identified by WC_ID. */
 CREATE TABLE SETTINGS (
   wc_id  INTEGER NOT NULL REFERENCES WCROOT (id) PRIMARY KEY,
-  store_pristines  INTEGER
+  store_pristine  INTEGER
 );
 
 PRAGMA user_version = 32;

Modified: subversion/branches/pristines-on-demand-on-mwf/subversion/libsvn_wc/wc-queries.sql
URL: http://svn.apache.org/viewvc/subversion/branches/pristines-on-demand-on-mwf/subversion/libsvn_wc/wc-queries.sql?rev=1905439&r1=1905438&r2=1905439&view=diff
==============================================================================
--- subversion/branches/pristines-on-demand-on-mwf/subversion/libsvn_wc/wc-queries.sql (original)
+++ subversion/branches/pristines-on-demand-on-mwf/subversion/libsvn_wc/wc-queries.sql Mon Nov 21 15:46:37 2022
@@ -1897,12 +1897,12 @@ SELECT pristine.checksum, pristine.hydra
 FROM pristine WHERE refcount = 0
 
 -- STMT_SELECT_SETTINGS
-SELECT store_pristines FROM settings WHERE wc_id = ?1
+SELECT store_pristine FROM settings WHERE wc_id = ?1
 
 -- STMT_UPSERT_SETTINGS
-INSERT INTO settings (wc_id, store_pristines)
+INSERT INTO settings (wc_id, store_pristine)
 VALUES (?1, ?2)
-ON CONFLICT(wc_id) DO UPDATE SET store_pristines=?2
+ON CONFLICT(wc_id) DO UPDATE SET store_pristine=?2
 
 /* ------------------------------------------------------------------------- */
 

Modified: subversion/branches/pristines-on-demand-on-mwf/subversion/libsvn_wc/wc.h
URL: http://svn.apache.org/viewvc/subversion/branches/pristines-on-demand-on-mwf/subversion/libsvn_wc/wc.h?rev=1905439&r1=1905438&r2=1905439&view=diff
==============================================================================
--- subversion/branches/pristines-on-demand-on-mwf/subversion/libsvn_wc/wc.h (original)
+++ subversion/branches/pristines-on-demand-on-mwf/subversion/libsvn_wc/wc.h Mon Nov 21 15:46:37 2022
@@ -541,7 +541,7 @@ svn_wc__internal_ensure_adm(svn_wc__db_t
                             const char *repos_uuid,
                             svn_revnum_t revision,
                             svn_depth_t depth,
-                            svn_boolean_t store_pristines,
+                            svn_boolean_t store_pristine,
                             apr_pool_t *scratch_pool);
 
 

Modified: subversion/branches/pristines-on-demand-on-mwf/subversion/libsvn_wc/wc_db.c
URL: http://svn.apache.org/viewvc/subversion/branches/pristines-on-demand-on-mwf/subversion/libsvn_wc/wc_db.c?rev=1905439&r1=1905438&r2=1905439&view=diff
==============================================================================
--- subversion/branches/pristines-on-demand-on-mwf/subversion/libsvn_wc/wc_db.c (original)
+++ subversion/branches/pristines-on-demand-on-mwf/subversion/libsvn_wc/wc_db.c Mon Nov 21 15:46:37 2022
@@ -1366,7 +1366,7 @@ init_db(/* output values */
         const char *root_node_repos_relpath,
         svn_revnum_t root_node_revision,
         svn_depth_t root_node_depth,
-        svn_boolean_t store_pristines,
+        svn_boolean_t store_pristine,
         const char *wcroot_abspath,
         apr_pool_t *scratch_pool)
 {
@@ -1393,7 +1393,7 @@ init_db(/* output values */
   if (target_format >= SVN_WC__SETTINGS_VERSION)
     {
       SVN_ERR(svn_sqlite__get_statement(&stmt, db, STMT_UPSERT_SETTINGS));
-      SVN_ERR(svn_sqlite__bindf(stmt, "id", *wc_id, store_pristines));
+      SVN_ERR(svn_sqlite__bindf(stmt, "id", *wc_id, store_pristine));
       SVN_ERR(svn_sqlite__insert(NULL, stmt));
     }
 
@@ -1444,7 +1444,7 @@ create_db(svn_sqlite__db_t **sdb,
           const char *root_node_repos_relpath,
           svn_revnum_t root_node_revision,
           svn_depth_t root_node_depth,
-          svn_boolean_t store_pristines,
+          svn_boolean_t store_pristine,
           svn_boolean_t exclusive,
           apr_int32_t timeout,
           apr_pool_t *result_pool,
@@ -1459,7 +1459,7 @@ create_db(svn_sqlite__db_t **sdb,
   SVN_SQLITE__WITH_LOCK(init_db(repos_id, wc_id,
                                 *sdb, target_format, repos_root_url, repos_uuid,
                                 root_node_repos_relpath, root_node_revision,
-                                root_node_depth, store_pristines, dir_abspath,
+                                root_node_depth, store_pristine, dir_abspath,
                                 scratch_pool),
                         *sdb);
 
@@ -1476,7 +1476,7 @@ svn_wc__db_init(svn_wc__db_t *db,
                 const char *repos_uuid,
                 svn_revnum_t initial_rev,
                 svn_depth_t depth,
-                svn_boolean_t store_pristines,
+                svn_boolean_t store_pristine,
                 apr_pool_t *scratch_pool)
 {
   svn_sqlite__db_t *sdb;
@@ -1506,7 +1506,7 @@ svn_wc__db_init(svn_wc__db_t *db,
   /* Create the SDB and insert the basic rows.  */
   SVN_ERR(create_db(&sdb, &repos_id, &wc_id, target_format, local_abspath,
                     repos_root_url, repos_uuid, SDB_FILE,
-                    repos_relpath, initial_rev, depth, store_pristines,
+                    repos_relpath, initial_rev, depth, store_pristine,
                     sqlite_exclusive, sqlite_timeout,
                     db->state_pool, scratch_pool));
 
@@ -1515,7 +1515,7 @@ svn_wc__db_init(svn_wc__db_t *db,
                         apr_pstrdup(db->state_pool, local_abspath),
                         sdb, wc_id, FORMAT_FROM_SDB,
                         FALSE /* auto-upgrade */,
-                        store_pristines,
+                        store_pristine,
                         db->state_pool, scratch_pool));
 
   /* Any previously cached children may now have a new WCROOT, most likely that
@@ -1550,7 +1550,7 @@ svn_wc__db_init(svn_wc__db_t *db,
 
 svn_error_t *
 svn_wc__db_get_settings(int *format_p,
-                        svn_boolean_t *store_pristines_p,
+                        svn_boolean_t *store_pristine_p,
                         svn_wc__db_t *db,
                         const char *local_abspath,
                         apr_pool_t *scratch_pool)
@@ -1567,8 +1567,8 @@ svn_wc__db_get_settings(int *format_p,
 
   if (format_p)
     *format_p = wcroot->format;
-  if (store_pristines_p)
-    *store_pristines_p = wcroot->store_pristines;
+  if (store_pristine_p)
+    *store_pristine_p = wcroot->store_pristine;
 
   return SVN_NO_ERROR;
 }
@@ -13459,7 +13459,7 @@ svn_wc__db_upgrade_begin(svn_sqlite__db_
                          const char *dir_abspath,
                          const char *repos_root_url,
                          const char *repos_uuid,
-                         svn_boolean_t store_pristines,
+                         svn_boolean_t store_pristine,
                          apr_pool_t *scratch_pool)
 {
   svn_wc__db_wcroot_t *wcroot;
@@ -13469,7 +13469,7 @@ svn_wc__db_upgrade_begin(svn_sqlite__db_
                     dir_abspath, repos_root_url, repos_uuid,
                     SDB_FILE,
                     NULL, SVN_INVALID_REVNUM, svn_depth_unknown,
-                    store_pristines,
+                    store_pristine,
                     TRUE /* exclusive */,
                     0 /* timeout */,
                     wc_db->state_pool, scratch_pool));
@@ -13479,7 +13479,7 @@ svn_wc__db_upgrade_begin(svn_sqlite__db_
                                                    dir_abspath),
                                        *sdb, *wc_id, FORMAT_FROM_SDB,
                                        FALSE /* auto-upgrade */,
-                                       store_pristines,
+                                       store_pristine,
                                        wc_db->state_pool, scratch_pool));
 
   /* The WCROOT is complete. Stash it into DB.  */

Modified: subversion/branches/pristines-on-demand-on-mwf/subversion/libsvn_wc/wc_db.h
URL: http://svn.apache.org/viewvc/subversion/branches/pristines-on-demand-on-mwf/subversion/libsvn_wc/wc_db.h?rev=1905439&r1=1905438&r2=1905439&view=diff
==============================================================================
--- subversion/branches/pristines-on-demand-on-mwf/subversion/libsvn_wc/wc_db_pristine.c (original)
+++ subversion/branches/pristines-on-demand-on-mwf/subversion/libsvn_wc/wc_db_pristine.c Mon Nov 21 15:46:37 2022
@@ -418,7 +418,7 @@ svn_wc__db_pristine_prepare_install(svn_
   install_data = apr_pcalloc(result_pool, sizeof(*install_data));
   install_data->wcroot = wcroot;
 
-  if (hydrated || wcroot->store_pristines)
+  if (hydrated || wcroot->store_pristine)
     {
       SVN_ERR_W(svn_stream__create_for_install(&install_data->inner_stream,
                                                temp_dir_abspath,

Modified: subversion/branches/pristines-on-demand-on-mwf/subversion/libsvn_wc/wc_db_private.h
URL: http://svn.apache.org/viewvc/subversion/branches/pristines-on-demand-on-mwf/subversion/libsvn_wc/wc_db_private.h?rev=1905439&r1=1905438&r2=1905439&view=diff
==============================================================================
--- subversion/branches/pristines-on-demand-on-mwf/subversion/libsvn_wc/wc_db_private.h (original)
+++ subversion/branches/pristines-on-demand-on-mwf/subversion/libsvn_wc/wc_db_private.h Mon Nov 21 15:46:37 2022
@@ -109,7 +109,7 @@ typedef struct svn_wc__db_wcroot_t {
 
   /* Whether to store the pristine contents of all files on disk or
      to fetch the contents on demand. */
-  svn_boolean_t store_pristines;
+  svn_boolean_t store_pristine;
 
 } svn_wc__db_wcroot_t;
 
@@ -130,7 +130,7 @@ svn_wc__db_pdh_create_wcroot(svn_wc__db_
                              apr_int64_t wc_id,
                              int format,
                              svn_boolean_t verify_format,
-                             svn_boolean_t store_pristines,
+                             svn_boolean_t store_pristine,
                              apr_pool_t *result_pool,
                              apr_pool_t *scratch_pool);
 

Modified: subversion/branches/pristines-on-demand-on-mwf/subversion/libsvn_wc/wc_db_wcroot.c
URL: http://svn.apache.org/viewvc/subversion/branches/pristines-on-demand-on-mwf/subversion/libsvn_wc/wc_db_wcroot.c?rev=1905439&r1=1905438&r2=1905439&view=diff
==============================================================================
--- subversion/branches/pristines-on-demand-on-mwf/subversion/libsvn_wc/wc_db_wcroot.c (original)
+++ subversion/branches/pristines-on-demand-on-mwf/subversion/libsvn_wc/wc_db_wcroot.c Mon Nov 21 15:46:37 2022
@@ -303,7 +303,7 @@ svn_wc__db_pdh_create_wcroot(svn_wc__db_
                              apr_int64_t wc_id,
                              int format,
                              svn_boolean_t verify_format,
-                             svn_boolean_t store_pristines,
+                             svn_boolean_t store_pristine,
                              apr_pool_t *result_pool,
                              apr_pool_t *scratch_pool)
 {
@@ -391,7 +391,7 @@ svn_wc__db_pdh_create_wcroot(svn_wc__db_
   (*wcroot)->owned_locks = apr_array_make(result_pool, 8,
                                           sizeof(svn_wc__db_wclock_t));
   (*wcroot)->access_cache = apr_hash_make(result_pool);
-  (*wcroot)->store_pristines = store_pristines;
+  (*wcroot)->store_pristine = store_pristine;
 
   /* SDB will be NULL for pre-NG working copies. We only need to run a
      cleanup when the SDB is present.  */
@@ -500,7 +500,7 @@ verify_stats_table(svn_sqlite__db_t *sdb
 
 /* Read and return the settings for WC_ID in SDB. */
 static svn_error_t *
-read_settings(svn_boolean_t *store_pristines_p,
+read_settings(svn_boolean_t *store_pristine_p,
               svn_sqlite__db_t *sdb,
               int format,
               apr_int64_t wc_id,
@@ -516,15 +516,15 @@ read_settings(svn_boolean_t *store_prist
       SVN_ERR(svn_sqlite__step(&have_row, stmt));
 
       if (have_row)
-        *store_pristines_p = svn_sqlite__column_boolean(stmt, 0);
+        *store_pristine_p = svn_sqlite__column_boolean(stmt, 0);
       else
-        *store_pristines_p = TRUE;
+        *store_pristine_p = TRUE;
 
       SVN_ERR(svn_sqlite__reset(stmt));
     }
   else
     {
-      *store_pristines_p = TRUE;
+      *store_pristine_p = TRUE;
     }
 
   return SVN_NO_ERROR;
@@ -536,7 +536,7 @@ read_settings(svn_boolean_t *store_prist
 static svn_error_t *
 fetch_sdb_info(apr_int64_t *wc_id,
                int *format,
-               svn_boolean_t *store_pristines,
+               svn_boolean_t *store_pristine,
                svn_sqlite__db_t *sdb,
                apr_pool_t *scratch_pool)
 {
@@ -547,7 +547,7 @@ fetch_sdb_info(apr_int64_t *wc_id,
         svn_wc__db_util_fetch_wc_id(wc_id, sdb, scratch_pool),
         svn_sqlite__read_schema_version(format, sdb, scratch_pool),
         verify_stats_table(sdb, *format, scratch_pool),
-        read_settings(store_pristines, sdb, *format, *wc_id, scratch_pool),
+        read_settings(store_pristine, sdb, *format, *wc_id, scratch_pool),
         sdb);
 
   return SVN_NO_ERROR;
@@ -800,10 +800,10 @@ try_symlink_as_dir:
 
       apr_int64_t wc_id;
       int format;
-      svn_boolean_t store_pristines;
+      svn_boolean_t store_pristine;
       svn_error_t *err;
 
-      err = fetch_sdb_info(&wc_id, &format, &store_pristines, sdb, scratch_pool);
+      err = fetch_sdb_info(&wc_id, &format, &store_pristine, sdb, scratch_pool);
       if (err)
         {
           if (err->apr_err == SVN_ERR_WC_CORRUPT)
@@ -824,7 +824,7 @@ try_symlink_as_dir:
                                           : local_abspath),
                             sdb, wc_id, format,
                             db->verify_format,
-                            store_pristines,
+                            store_pristine,
                             db->state_pool, scratch_pool);
       if (err && (err->apr_err == SVN_ERR_WC_UNSUPPORTED_FORMAT ||
                   err->apr_err == SVN_ERR_WC_UPGRADE_REQUIRED) &&
@@ -1080,7 +1080,7 @@ svn_wc__db_drop_root(svn_wc__db_t *db,
  */
 svn_error_t *
 svn_wc__settings_from_context(int *format_p,
-                              svn_boolean_t *store_pristines_p,
+                              svn_boolean_t *store_pristine_p,
                               svn_wc_context_t *wc_ctx,
                               const char *local_abspath,
                               apr_pool_t *scratch_pool)
@@ -1094,7 +1094,7 @@ svn_wc__settings_from_context(int *forma
   if (0 == keys->nelts)
     {
       *format_p = SVN_WC__DEFAULT_VERSION;
-      *store_pristines_p = TRUE;
+      *store_pristine_p = TRUE;
       return SVN_NO_ERROR;
     }
 
@@ -1117,7 +1117,7 @@ svn_wc__settings_from_context(int *forma
             /* Found an exact match in the WC context. */
             svn_wc__db_wcroot_t *wcroot = svn_hash_gets(dir_data, here);
             *format_p = wcroot->format;
-            *store_pristines_p = wcroot->store_pristines;
+            *store_pristine_p = wcroot->store_pristine;
             return SVN_NO_ERROR;
           }
       }
@@ -1130,7 +1130,7 @@ svn_wc__settings_from_context(int *forma
             /* Found the parent path in the WC context. */
             svn_wc__db_wcroot_t *wcroot = svn_hash_gets(dir_data, prev);
             *format_p = wcroot->format;
-            *store_pristines_p = wcroot->store_pristines;
+            *store_pristine_p = wcroot->store_pristine;
             return SVN_NO_ERROR;
           }
       }
@@ -1139,7 +1139,7 @@ svn_wc__settings_from_context(int *forma
   /* Find the oldest format recorded in the WC context. */
   {
     int oldest_format = SVN_WC__VERSION;
-    svn_boolean_t store_pristines = TRUE;
+    svn_boolean_t store_pristine = TRUE;
     apr_hash_index_t *hi;
 
     for (hi = apr_hash_first(scratch_pool, dir_data);
@@ -1150,12 +1150,12 @@ svn_wc__settings_from_context(int *forma
         if (wcroot->format < oldest_format)
           {
             oldest_format = wcroot->format;
-            store_pristines = wcroot->store_pristines;
+            store_pristine = wcroot->store_pristine;
           }
       }
 
     *format_p = oldest_format;
-    *store_pristines_p = store_pristines;
+    *store_pristine_p = store_pristine;
     return SVN_NO_ERROR;
   }
 }

Modified: subversion/branches/pristines-on-demand-on-mwf/subversion/svn/checkout-cmd.c
URL: http://svn.apache.org/viewvc/subversion/branches/pristines-on-demand-on-mwf/subversion/svn/checkout-cmd.c?rev=1905439&r1=1905438&r2=1905439&view=diff
==============================================================================
--- subversion/branches/pristines-on-demand-on-mwf/subversion/svn/checkout-cmd.c (original)
+++ subversion/branches/pristines-on-demand-on-mwf/subversion/svn/checkout-cmd.c Mon Nov 21 15:46:37 2022
@@ -173,7 +173,7 @@ svn_cl__checkout(apr_getopt_t *os,
                opt_state->ignore_externals,
                opt_state->force,
                opt_state->compatible_version,
-               opt_state->store_pristines,
+               opt_state->store_pristine,
                ctx, subpool));
     }
   svn_pool_destroy(subpool);

Modified: subversion/branches/pristines-on-demand-on-mwf/subversion/svn/cl.h
URL: http://svn.apache.org/viewvc/subversion/branches/pristines-on-demand-on-mwf/subversion/svn/cl.h?rev=1905439&r1=1905438&r2=1905439&view=diff
==============================================================================
--- subversion/branches/pristines-on-demand-on-mwf/subversion/svn/cl.h (original)
+++ subversion/branches/pristines-on-demand-on-mwf/subversion/svn/cl.h Mon Nov 21 15:46:37 2022
@@ -276,7 +276,7 @@ typedef struct svn_cl__opt_state_t
       svn_cl__viewspec_svn11
   } viewspec;                     /* value of --x-viewspec */
   svn_version_t *compatible_version; /* working copy compatibility version */
-  svn_boolean_t store_pristines;
+  svn_boolean_t store_pristine;
 } svn_cl__opt_state_t;
 
 /* Conflict stats for operations such as update and merge. */
@@ -377,7 +377,7 @@ typedef enum svn_cl__longopt_t {
   opt_drop,
   opt_viewspec,
   opt_compatible_version,
-  opt_store_pristines
+  opt_store_pristine
 } svn_cl__longopt_t;
 
 /* Options for giving a log message.  (Some of these also have other uses.)

Modified: subversion/branches/pristines-on-demand-on-mwf/subversion/svn/svn.c
URL: http://svn.apache.org/viewvc/subversion/branches/pristines-on-demand-on-mwf/subversion/svn/svn.c?rev=1905439&r1=1905438&r2=1905439&view=diff
==============================================================================
--- subversion/branches/pristines-on-demand-on-mwf/subversion/svn/svn.c (original)
+++ subversion/branches/pristines-on-demand-on-mwf/subversion/svn/svn.c Mon Nov 21 15:46:37 2022
@@ -371,7 +371,7 @@ const apr_getopt_option_t svn_cl__option
                        "                             "
                        "version ARG (\"1.8\", \"1.9.5\", etc.)")},
 
-  {"store-pristines", opt_store_pristines, 1,
+  {"store-pristine", opt_store_pristine, 1,
                        N_("Configure the working copy to either store local\n"
                        "                             "
                        "copies of pristine contents ('yes') or to fetch\n"
@@ -554,7 +554,7 @@ svn_cl__cmd_table_main[] =
      "  reporting the action taken.\n"
     )},
     {'r', 'q', 'N', opt_depth, opt_force, opt_ignore_externals,
-     opt_compatible_version, opt_store_pristines},
+     opt_compatible_version, opt_store_pristine},
     {{'N', N_("obsolete; same as --depth=files")}} },
 
   { "cleanup", svn_cl__cleanup, {0}, {N_(
@@ -2189,7 +2189,7 @@ sub_main(int *exit_code, int argc, const
   opt_state.accept_which = svn_cl__accept_unspecified;
   opt_state.show_revs = svn_cl__show_revs_invalid;
   opt_state.file_size_unit = SVN_CL__SIZE_UNIT_NONE;
-  opt_state.store_pristines = svn_tristate_unknown;
+  opt_state.store_pristine = svn_tristate_unknown;
 
   /* No args?  Show usage. */
   if (argc <= 1)
@@ -2746,14 +2746,14 @@ sub_main(int *exit_code, int argc, const
       case opt_compatible_version:
         SVN_ERR(parse_compatible_version(&opt_state, opt_arg, pool));
         break;
-      case opt_store_pristines:
+      case opt_store_pristine:
         SVN_ERR(svn_utf_cstring_to_utf8(&utf8_opt_arg, opt_arg, pool));
-        opt_state.store_pristines = svn_tristate__from_word(utf8_opt_arg);
-        if (opt_state.store_pristines == svn_tristate_unknown)
+        opt_state.store_pristine = svn_tristate__from_word(utf8_opt_arg);
+        if (opt_state.store_pristine == svn_tristate_unknown)
           return svn_error_createf(SVN_ERR_CL_ARG_PARSING_ERROR, NULL,
                                    _("Unknown value '%s' for %s.\n"
                                      "Supported values: %s"),
-                                   utf8_opt_arg, "--store-pristines", "yes, no");
+                                   utf8_opt_arg, "--store-pristine", "yes, no");
         break;
       default:
         /* Hmmm. Perhaps this would be a good place to squirrel away

Modified: subversion/branches/pristines-on-demand-on-mwf/subversion/tests/cmdline/pristines_on_demand_tests.py
URL: http://svn.apache.org/viewvc/subversion/branches/pristines-on-demand-on-mwf/subversion/tests/cmdline/pristines_on_demand_tests.py?rev=1905439&r1=1905438&r2=1905439&view=diff
==============================================================================
--- subversion/branches/pristines-on-demand-on-mwf/subversion/tests/cmdline/pristines_on_demand_tests.py (original)
+++ subversion/branches/pristines-on-demand-on-mwf/subversion/tests/cmdline/pristines_on_demand_tests.py Mon Nov 21 15:46:37 2022
@@ -54,7 +54,7 @@ def simple_checkout(sbox):
                                           expected_output,
                                           expected_disk,
                                           [],
-                                          "--store-pristines=no")
+                                          "--store-pristine=no")
 
 @SkipUnless(svntest.main.is_wc_pristines_on_demand_supported)
 def simple_commit(sbox):
@@ -68,7 +68,7 @@ def simple_commit(sbox):
                                           expected_output,
                                           expected_disk,
                                           [],
-                                          "--store-pristines=no")
+                                          "--store-pristine=no")
 
   sbox.simple_append('file', 'contents')
   sbox.simple_add('file')
@@ -96,7 +96,7 @@ def simple_update(sbox):
                                           expected_output,
                                           expected_wc,
                                           [],
-                                          "--store-pristines=no")
+                                          "--store-pristine=no")
   sbox.simple_append('file', 'foo')
   sbox.simple_add('file')
   sbox.simple_commit(message='r1')
@@ -133,7 +133,7 @@ def simple_status(sbox):
                                           expected_output,
                                           expected_wc,
                                           [],
-                                          "--store-pristines=no")
+                                          "--store-pristine=no")
   sbox.simple_append('file', 'foo')
   sbox.simple_add('file')
 
@@ -184,7 +184,7 @@ def simple_diff(sbox):
                                           expected_output,
                                           expected_wc,
                                           [],
-                                          "--store-pristines=no")
+                                          "--store-pristine=no")
   sbox.simple_append('file', 'foo\n')
   sbox.simple_add('file')
   sbox.simple_commit(message='r1')
@@ -212,7 +212,7 @@ def simple_revert(sbox):
                                           expected_output,
                                           expected_wc,
                                           [],
-                                          "--store-pristines=no")
+                                          "--store-pristine=no")
   sbox.simple_append('file', 'foo\n')
   sbox.simple_add('file')
   sbox.simple_commit(message='r1')
@@ -240,7 +240,7 @@ def update_modified_file(sbox):
                                           expected_output,
                                           expected_wc,
                                           [],
-                                          "--store-pristines=no")
+                                          "--store-pristine=no")
   sbox.simple_append('file', 'foo')
   sbox.simple_add('file')
   sbox.simple_commit(message='r1')

Modified: subversion/branches/pristines-on-demand-on-mwf/subversion/tests/libsvn_client/client-test.c
URL: http://svn.apache.org/viewvc/subversion/branches/pristines-on-demand-on-mwf/subversion/tests/libsvn_client/client-test.c?rev=1905439&r1=1905438&r2=1905439&view=diff
==============================================================================
--- subversion/branches/pristines-on-demand-on-mwf/subversion/tests/libsvn_client/client-test.c (original)
+++ subversion/branches/pristines-on-demand-on-mwf/subversion/tests/libsvn_client/client-test.c Mon Nov 21 15:46:37 2022
@@ -393,7 +393,7 @@ test_patch(const svn_test_opts_t *opts,
                                &peg_rev, &rev, svn_depth_infinity,
                                TRUE, FALSE,
                                opts->wc_format_version,
-                               opts->store_pristines,
+                               opts->store_pristine,
                                ctx, pool));
 
   /* Create the patch file. */
@@ -469,7 +469,7 @@ test_wc_add_scenarios(const svn_test_opt
   SVN_ERR(svn_client_checkout4(NULL, repos_url, wc_path, &peg_rev, &rev,
                                svn_depth_infinity, FALSE, FALSE,
                                opts->wc_format_version,
-                               opts->store_pristines,
+                               opts->store_pristine,
                                ctx, pool));
 
   /* Now checkout again as wc_path/NEW */
@@ -477,7 +477,7 @@ test_wc_add_scenarios(const svn_test_opt
   SVN_ERR(svn_client_checkout4(NULL, repos_url, new_dir_path, &peg_rev, &rev,
                                svn_depth_infinity, FALSE, FALSE,
                                opts->wc_format_version,
-                               opts->store_pristines,
+                               opts->store_pristine,
                                ctx, pool));
 
   ex_dir_path = svn_dirent_join(wc_path, "NEW_add", pool);
@@ -639,7 +639,7 @@ test_16k_add(const svn_test_opts_t *opts
                                &peg_rev, &rev, svn_depth_infinity,
                                TRUE, FALSE,
                                opts->wc_format_version,
-                               opts->store_pristines,
+                               opts->store_pristine,
                                ctx, pool));
 
   for (i = 0; i < 16384; i++)
@@ -772,7 +772,7 @@ test_foreign_repos_copy(const svn_test_o
                                svn_depth_infinity,
                                FALSE, FALSE,
                                opts->wc_format_version,
-                               opts->store_pristines,
+                               opts->store_pristine,
                                ctx, pool));
 
   SVN_ERR(svn_client__ra_session_from_path2(&ra_session, &loc,
@@ -843,7 +843,7 @@ test_suggest_mergesources(const svn_test
                                &head_rev, &head_rev, svn_depth_empty,
                                FALSE, FALSE,
                                opts->wc_format_version,
-                               opts->store_pristines,
+                               opts->store_pristine,
                                ctx, pool));
 
   SVN_ERR(svn_client_suggest_merge_sources(&results,
@@ -992,7 +992,7 @@ test_remote_only_status(const svn_test_o
                                wc_path, &rev, &rev, svn_depth_immediates,
                                FALSE, FALSE,
                                opts->wc_format_version,
-                               opts->store_pristines,
+                               opts->store_pristine,
                                ctx, pool));
 
   /* Add a local file; this is a double-check to make sure that

Modified: subversion/branches/pristines-on-demand-on-mwf/subversion/tests/libsvn_client/conflicts-test.c
URL: http://svn.apache.org/viewvc/subversion/branches/pristines-on-demand-on-mwf/subversion/tests/libsvn_client/conflicts-test.c?rev=1905439&r1=1905438&r2=1905439&view=diff
==============================================================================
--- subversion/branches/pristines-on-demand-on-mwf/subversion/tests/libsvn_client/conflicts-test.c (original)
+++ subversion/branches/pristines-on-demand-on-mwf/subversion/tests/libsvn_client/conflicts-test.c Mon Nov 21 15:46:37 2022
@@ -6118,7 +6118,7 @@ test_file_vs_dir_move_merge_assertion_fa
                                wc_path, &peg_rev, &opt_rev, svn_depth_infinity,
                                TRUE, FALSE,
                                opts->wc_format_version,
-                               opts->store_pristines,
+                               opts->store_pristine,
                                ctx, pool));
 
   SVN_ERR(svn_client_merge_peg5(svn_path_url_add_component2(b->repos_url, "A",

Modified: subversion/branches/pristines-on-demand-on-mwf/subversion/tests/libsvn_wc/entries-compat.c
URL: http://svn.apache.org/viewvc/subversion/branches/pristines-on-demand-on-mwf/subversion/tests/libsvn_wc/entries-compat.c?rev=1905439&r1=1905438&r2=1905439&view=diff
==============================================================================
--- subversion/branches/pristines-on-demand-on-mwf/subversion/tests/libsvn_wc/entries-compat.c (original)
+++ subversion/branches/pristines-on-demand-on-mwf/subversion/tests/libsvn_wc/entries-compat.c Mon Nov 21 15:46:37 2022
@@ -644,7 +644,7 @@ test_access_baton_like_locking(const svn
                                svn_path_url_add_component2(url, "sub-wc", pool),
                                repos_root_url, repos_uuid,
                                0, svn_depth_infinity,
-                               opts->store_pristines, pool));
+                               opts->store_pristine, pool));
 
     SVN_ERR(svn_wc__db_is_switched(&is_root, NULL, NULL, wc_ctx->db, subdir,
                                    pool));

Modified: subversion/branches/pristines-on-demand-on-mwf/subversion/tests/libsvn_wc/utils.c
URL: http://svn.apache.org/viewvc/subversion/branches/pristines-on-demand-on-mwf/subversion/tests/libsvn_wc/utils.c?rev=1905439&r1=1905438&r2=1905439&view=diff
==============================================================================
--- subversion/branches/pristines-on-demand-on-mwf/subversion/tests/libsvn_wc/utils.c (original)
+++ subversion/branches/pristines-on-demand-on-mwf/subversion/tests/libsvn_wc/utils.c Mon Nov 21 15:46:37 2022
@@ -108,7 +108,7 @@ create_repos_and_wc(const char **repos_u
                                  FALSE /* ignore_externals */,
                                  FALSE /* allow_unver_obstructions */,
                                  opts->wc_format_version,
-                                 opts->store_pristines,
+                                 opts->store_pristine,
                                  ctx, subpool));
     svn_pool_destroy(subpool);
   }

Modified: subversion/branches/pristines-on-demand-on-mwf/subversion/tests/svn_test.h
URL: http://svn.apache.org/viewvc/subversion/branches/pristines-on-demand-on-mwf/subversion/tests/svn_test.h?rev=1905439&r1=1905438&r2=1905439&view=diff
==============================================================================
--- subversion/branches/pristines-on-demand-on-mwf/subversion/tests/svn_test.h (original)
+++ subversion/branches/pristines-on-demand-on-mwf/subversion/tests/svn_test.h Mon Nov 21 15:46:37 2022
@@ -219,7 +219,7 @@ typedef struct svn_test_opts_t
   /* WC format version to use for all tests (except tests for a specific format) */
   const svn_version_t *wc_format_version;
   svn_boolean_t verbose;
-  svn_tristate_t store_pristines;
+  svn_tristate_t store_pristine;
   /* Add future "arguments" here. */
 } svn_test_opts_t;
 

Modified: subversion/branches/pristines-on-demand-on-mwf/subversion/tests/svn_test_main.c
URL: http://svn.apache.org/viewvc/subversion/branches/pristines-on-demand-on-mwf/subversion/tests/svn_test_main.c?rev=1905439&r1=1905438&r2=1905439&view=diff
==============================================================================
--- subversion/branches/pristines-on-demand-on-mwf/subversion/tests/svn_test_main.c (original)
+++ subversion/branches/pristines-on-demand-on-mwf/subversion/tests/svn_test_main.c Mon Nov 21 15:46:37 2022
@@ -809,7 +809,7 @@ svn_test_main(int argc, const char *argv
 
   opts.fs_type = DEFAULT_FS_TYPE;
   opts.wc_format_version = svn_wc__min_supported_format_version();
-  opts.store_pristines = svn_tristate_unknown;
+  opts.store_pristine = svn_tristate_unknown;
 
   /* Initialize APR (Apache pools) */
   if (apr_initialize() != APR_SUCCESS)
--- subversion/branches/pristines-on-demand-on-mwf/subversion/include/private/svn_wc_private.h (original)
+++ subversion/branches/pristines-on-demand-on-mwf/subversion/include/private/svn_wc_private.h Mon Nov 21 15:46:37 2022
@@ -2231,7 +2231,7 @@ const svn_version_t *
 svn_wc__min_supported_format_version(void);
 
 /**
  * Set @a *format_p and @a *store_pristines_p to the settings of the
  * nearest parent working copy root of @a local_abspath in @a wc_ctx,
  * or to settings of any root stored there, preferring the one with
  * the oldest format. If @a wc_ctx is empty, return the library's
@@ -2243,7 +2243,7 @@ svn_wc__min_supported_format_version(voi
  */
 svn_error_t *
 svn_wc__settings_from_context(int *format_p,
-                              svn_boolean_t *store_pristines_p,
+                              svn_boolean_t *store_pristine_p,
                               svn_wc_context_t *wc_ctx,
                               const char *local_abspath,
                               apr_pool_t *scratch_pool);
@@ -2253,7 +2253,7 @@ svn_wc__settings_from_context(int *forma
  * local_abspath is a working copy subdir with schema version @a target_format
  * based on @a url at @a revision, with depth @a depth, with repository UUID
  * @a repos_uuid and repository root URL @a repos_root_url, and with the
- * @a store_pristines setting value.
+ * @a store_pristine setting value.
  *
  * @a depth must be a definite depth, it cannot be #svn_depth_unknown.
  * @a repos_uuid and @a repos_root_url MUST NOT be @c NULL, and
@@ -2284,12 +2284,12 @@ svn_wc__ensure_adm(svn_wc_context_t *wc_
                    const char *repos_uuid,
                    svn_revnum_t revision,
                    svn_depth_t depth,
-                   svn_boolean_t store_pristines,
+                   svn_boolean_t store_pristine,
                    apr_pool_t *scratch_pool);
 
 /**
  * Upgrade the working copy at @a local_abspath to the metadata storage
  * format indicated by @a target_format.  Use the @a store_pristines
  * settings value for the upgraded working copy.  @a local_abspath
  * should be an absolute path to the root of the working copy.
  *
@@ -2312,7 +2312,7 @@ svn_error_t *
 svn_wc__upgrade(svn_wc_context_t *wc_ctx,
                 const char *local_abspath,
                 int target_format,
-                svn_boolean_t store_pristines,
+                svn_boolean_t store_pristine,
                 svn_wc_upgrade_get_repos_info_t repos_info_func,
                 void *repos_info_baton,
                 svn_cancel_func_t cancel_func,
@@ -2348,11 +2348,11 @@ svn_wc__textbase_sync(svn_wc_context_t *
                       void *cancel_baton,
                       apr_pool_t *scratch_pool);
 
 /* Return the working copy settings *FORMAT_P and *STORE_PRISTINES_P for
    LOCAL_ABSPATH in WC_CTX. */
 svn_error_t *
 svn_wc__get_settings(int *format_p,
-                     svn_boolean_t *store_pristines_p,
+                     svn_boolean_t *store_pristine_p,
                      svn_wc_context_t *wc_ctx,
                      const char *local_abspath,
                      apr_pool_t *scratch_pool);
@@ -2231,7 +2231,7 @@ const svn_version_t *
 
 /**
- * Set @a *format_p and @a *store_pristines_p to the settings of the
+ * Set @a *format_p and @a *store_pristine_p to the settings of the
  * nearest parent working copy root of @a local_abspath in @a wc_ctx,
  * or to settings of any root stored there, preferring the one with
@@ -2284,12 +2284,12 @@ svn_wc__ensure_adm(svn_wc_context_t *wc_
 /**
  * Upgrade the working copy at @a local_abspath to the metadata storage
- * format indicated by @a target_format.  Use the @a store_pristines
+ * format indicated by @a target_format.  Use the @a store_pristine
  * settings value for the upgraded working copy.  @a local_abspath
  * should be an absolute path to the root of the working copy.
@@ -2348,11 +2348,11 @@ svn_wc__textbase_sync(svn_wc_context_t *
                       apr_pool_t *scratch_pool);
 
-/* Return the working copy settings *FORMAT_P and *STORE_PRISTINES_P for
+/* Return the working copy settings *FORMAT_P and *STORE_PRISTINE_P for
    LOCAL_ABSPATH in WC_CTX. */
 svn_error_t *

Modified: subversion/branches/pristines-on-demand-on-mwf/subversion/include/svn_client.h
URL: http://svn.apache.org/viewvc/subversion/branches/pristines-on-demand-on-mwf/subversion/include/svn_client.h?rev=1905439&r1=1905438&r2=1905439&view=diff
==============================================================================
--- subversion/branches/pristines-on-demand-on-mwf/subversion/include/svn_client.h (original)
+++ subversion/branches/pristines-on-demand-on-mwf/subversion/include/svn_client.h Mon Nov 21 15:46:37 2022
@@ -1245,7 +1245,7 @@ svn_client_args_to_target_array(apr_arra
  *              @c NULL means the library's version.
  *              See svn_client_default_wc_version(),
  *              svn_client_get_wc_formats_supported().
  * @param[in] store_pristines  If #svn_tristate_true, the pristine contents of
  *              all files in the working copy will be stored on disk. <br>
  *              If #svn_tristate_false, the pristine contents will be fetched
  *              on-demand when required by the operation. <br>
@@ -1279,7 +1279,7 @@ svn_client_checkout4(svn_revnum_t *resul
                      svn_boolean_t ignore_externals,
                      svn_boolean_t allow_unver_obstructions,
                      const svn_version_t *wc_format_version,
-                     svn_tristate_t store_pristines,
+                     svn_tristate_t store_pristine,
                      svn_client_ctx_t *ctx,
                      apr_pool_t *pool);
 
@@ -1245,7 +1245,7 @@ svn_client_args_to_target_array(apr_arra
  *              See svn_client_default_wc_version(),
  *              svn_client_get_wc_formats_supported().
- * @param[in] store_pristines  If #svn_tristate_true, the pristine contents of
+ * @param[in] store_pristine  If #svn_tristate_true, the pristine contents of
  *              all files in the working copy will be stored on disk. <br>
  *              If #svn_tristate_false, the pristine contents will be fetched

Modified: subversion/branches/pristines-on-demand-on-mwf/subversion/libsvn_client/checkout.c
URL: http://svn.apache.org/viewvc/subversion/branches/pristines-on-demand-on-mwf/subversion/libsvn_client/checkout.c?rev=1905439&r1=1905438&r2=1905439&view=diff
==============================================================================
--- subversion/branches/pristines-on-demand-on-mwf/subversion/libsvn_wc/wc_db.h (original)
+++ subversion/branches/pristines-on-demand-on-mwf/subversion/libsvn_wc/wc_db.h Mon Nov 21 15:46:37 2022
@@ -310,17 +310,17 @@ svn_wc__db_init(svn_wc__db_t *db,
                 const char *repos_uuid,
                 svn_revnum_t initial_rev,
                 svn_depth_t depth,
-                svn_boolean_t store_pristines,
+                svn_boolean_t store_pristine,
                 apr_pool_t *scratch_pool);
 
 /* Return the working copy settings *FORMAT_P and *STORE_PRISTINES_P for
    LOCAL_ABSPATH in DB.
 
    Use SCRATCH_POOL for temporary allocations.
 */
 svn_error_t *
 svn_wc__db_get_settings(int *format_p,
-                        svn_boolean_t *store_pristines_p,
+                        svn_boolean_t *store_pristine_p,
                         svn_wc__db_t *db,
                         const char *local_abspath,
                         apr_pool_t *scratch_pool);
@@ -2983,7 +2983,7 @@ svn_wc__db_upgrade_begin(svn_sqlite__db_
                          const char *local_dir_abspath,
                          const char *repos_root_url,
                          const char *repos_uuid,
-                         svn_boolean_t store_pristines,
+                         svn_boolean_t store_pristine,
                          apr_pool_t *scratch_pool);
 
 /* Simply insert (or replace) one row in the EXTERNALS table. */
@@ -310,17 +310,17 @@ svn_wc__db_init(svn_wc__db_t *db,
                 apr_pool_t *scratch_pool);
 
-/* Return the working copy settings *FORMAT_P and *STORE_PRISTINES_P for
+/* Return the working copy settings *FORMAT_P and *STORE_PRISTINE_P for
    LOCAL_ABSPATH in DB.
 

Modified: subversion/branches/pristines-on-demand-on-mwf/subversion/libsvn_wc/wc_db_pristine.c
URL: http://svn.apache.org/viewvc/subversion/branches/pristines-on-demand-on-mwf/subversion/libsvn_wc/wc_db_pristine.c?rev=1905439&r1=1905438&r2=1905439&view=diff
==============================================================================